@@ -17,7 +17,7 @@ from typing import Optional
 
 # Third-party imports
 # -------------------
-from fastapi import APIRouter, Request, HTTPException
+from fastapi import APIRouter, Cookie, Request, HTTPException
 from fastapi.responses import FileResponse, HTMLResponse, RedirectResponse
 from fastapi.templating import Jinja2Templates
 from jinja2.exceptions import TemplateNotFound
@@ -143,6 +143,7 @@ async def serve_page(
     request: Request,
     course_name: constr(max_length=512),  # type: ignore
     pagepath: constr(max_length=512),  # type: ignore
+    RS_info: Optional[str] = Cookie(None),
     mode: Optional[str] = None,
 ):
     if mode and mode == "browsing":
@@ -178,9 +179,14 @@ async def serve_page(
         # The user is logged in, but their "current course" is not this one.
         # Send them to the courses page so they can properly switch courses.
         if user and user.course_name != course_name:
+            user_course_row = await fetch_course(user.course_name)
             rslogger.debug(
                 f"Course mismatch: course name: {user.course_name} does not match requested course: {course_name} redirecting"
             )
+            if user_course_row.base_course == course_name:
+                return RedirectResponse(
+                    url=f"/ns/books/published/{user.course_name}/{pagepath}"
+                )
             return RedirectResponse(
                 url=f"/runestone/default/courses?requested_course={course_name}&current_course={user.course_name}"
             )
@@ -224,6 +230,12 @@ async def serve_page(
     if "enable_compare_me" not in course_attrs:
         course_attrs["enable_compare_me"] = "true"
 
+    reading_list = []
+    if RS_info:
+        values = json.loads(RS_info)
+        if "readings" in values:
+            reading_list = values["readings"]
+
     #   TODO: provide the template google_ga as well as ad servings stuff
     #   settings.google_ga
     await create_useinfo_entry(
@@ -256,7 +268,7 @@ async def serve_page(
         serve_ad=serve_ad,
         is_instructor="true" if user_is_instructor else "false",
         use_services="true" if use_services else "false",
-        readings=[],
+        readings=reading_list,
         **course_attrs,
     )
     # See `templates <https://fastapi.tiangolo.com/advanced/templates/>`_.
